@@ -170,28 +170,49 @@ class Action():
                 disable_web_page_preview = None
                 if "disable_web_page_preview" in item:
                     disable_web_page_preview = item["disable_web_page_preview"]
+
+                text = item["text"]
+                
                 print("type: ", type(update))
                 print("update: ", update)
                 print("context: ", str(context.user_data))
                 if type(update) == CallbackQuery:
-                    update.from_user.send_message(item["text"].format(
+                    update.from_user.send_message(text.format(
                         **context.user_data), reply_markup=reply_markup, parse_mode=parse_mode, disable_web_page_preview=disable_web_page_preview)
                 elif update.callback_query:
-                    update.callback_query.from_user.send_message(item["text"].format(
+                    update.callback_query.from_user.send_message(text.format(
                         **context.user_data), reply_markup=reply_markup, parse_mode=parse_mode, disable_web_page_preview=disable_web_page_preview)
                 elif update.poll_answer:
-                    update.poll_answer.user.send_message(item["text"].format(
+                    update.poll_answer.user.send_message(text.format(
                         **context.user_data), reply_markup=reply_markup, parse_mode=parse_mode, disable_web_page_preview=disable_web_page_preview)
                 else:
-                    update.message.reply_text(item["text"].format(
+                    update.message.reply_text(text.format(
                         **context.user_data), reply_markup=reply_markup, parse_mode=parse_mode, disable_web_page_preview=disable_web_page_preview)
             elif item["type"] == "photo":
+                if "caption" in item.keys():
+                    caption = item["caption"]
+                else:
+                    caption = None
                 if type(update) != CallbackQuery and update.poll_answer:
                     update.poll_answer.user.send_photo(
-                        open(item["file"], 'rb'), reply_markup=reply_markup)
+                        open(item["file"], 'rb'), caption=caption, reply_markup=reply_markup)
                 else:
                     update.message.reply_photo(
-                        open(item["file"], 'rb'), reply_markup=reply_markup)
+                        open(item["file"], 'rb'), caption=caption, reply_markup=reply_markup)
+
+            elif item["type"] == "document":
+                if "caption" in item.keys():
+                    caption = item["caption"]
+                else:
+                    caption = None
+
+                if type(update) != CallbackQuery and update.poll_answer:
+                    update.poll_answer.user.send_document(
+                        open(item["file"], 'rb'), caption=caption, reply_markup=reply_markup)
+                else:
+                    update.message.reply_document(
+                        open(item["file"], 'rb'), caption=caption, reply_markup=reply_markup)
+
             elif item["type"] == "audio":
                 print("reply_markup: {}".format(reply_markup))
                 update.message.reply_audio(open(
