@@ -5,8 +5,8 @@ from telegram import (Update)
 from telegram.ext import (CallbackContext)
 
 def generate_gif(im1, im2):
-    im1 = im1.resize((round(im1.size[0]*1), round(im1.size[1]*1)))
-    im2 = im2.resize((round(im1.size[0]), round(im1.size[1])))
+    im1 = im1.resize((round(im2.size[0]*1), round(im2.size[1]*1)))
+    im1 = im1.convert(im2.mode)
 
     images = []
     frames = 10
@@ -36,7 +36,7 @@ def overlay_images(background, foreground):
     bio.seek(0)
     return bio
 
-def eval_gif_generation(update: Update, context: CallbackContext, picture):
+def telegram_eval_gif_generation(update: Update, context: CallbackContext, picture):
     im_bytes = update.message.photo[-1].get_file().download_as_bytearray()
 
     im_file = BytesIO(im_bytes)  # convert image to file-like object
@@ -47,5 +47,5 @@ def eval_gif_generation(update: Update, context: CallbackContext, picture):
 
     update.message.reply_document(gif)
 
-action_functions = {"eval_gif_generation": eval_gif_generation,
+telegram_action_functions = {"eval_gif_generation": telegram_eval_gif_generation,
                     }
\ No newline at end of file
