@@ -1,19 +1,19 @@
 from telegram import (ReplyKeyboardRemove, Update)
 from telegram.ext import (CallbackContext)
 
-def append_to_context(update: Update, context: CallbackContext, key, value):
+def telegram_append_to_context(update: Update, context: CallbackContext, key, value):
     if not key in context.user_data:
         context.user_data[key] = []
     context.user_data[key].append(value)
 
-def check_in_context(update: Update, context: CallbackContext, key, value, doppelte_antwort):
+def telegram_check_in_context(update: Update, context: CallbackContext, key, value, doppelte_antwort):
     if key in context.user_data:
         if value in context.user_data[key]:
             update.message.reply_text(doppelte_antwort,
                                   reply_markup=ReplyKeyboardRemove())
             return "{}_FRAGE".format(key.upper())
 
-def eval_list(update: Update, context: CallbackContext, answer_id_name_list, poi, response_text):
+def telegram_eval_list(update: Update, context: CallbackContext, answer_id_name_list, poi, response_text):
     if not poi in context.user_data:
         context.user_data[poi] = []
 
@@ -28,7 +28,7 @@ def eval_list(update: Update, context: CallbackContext, answer_id_name_list, poi
     update.message.reply_text(response_text,
                               reply_markup=ReplyKeyboardRemove())
 
-action_functions = {"append_to_context": append_to_context,
-                    "check_in_context": check_in_context,
-                    "eval_list": eval_list
+telegram_action_functions = {"append_to_context": telegram_append_to_context,
+                    "check_in_context": telegram_check_in_context,
+                    "eval_list": telegram_eval_list
                     }
\ No newline at end of file
