@@ -53,7 +53,11 @@ WOHIN_PATTERN = re.compile(
     "GPS|"
     "way|"
     "where|"
-    "location"
+    "location|"
+    "Hilfe|"
+    "hilfe|"
+    "wie|"
+    "Wie"
     ")$"
 )
 
