@@ -1,7 +1,7 @@
 from telegram import (Update, ReplyKeyboardRemove)
 from telegram.ext import (CallbackContext)
 
-def eval_jahreszahl(update: Update, context: CallbackContext, echter_wert, richtig_text, vorher_singular_text, vorher_plural_text, spaeter_singular_text, spaeter_plural_text):
+def telegram_eval_jahreszahl(update: Update, context: CallbackContext, echter_wert, richtig_text, vorher_singular_text, vorher_plural_text, spaeter_singular_text, spaeter_plural_text):
     import re
     echter_wert = int(echter_wert)
     schaetzung = int(re.findall(r"\d{1,4}", update.message.text)[0])
@@ -23,7 +23,7 @@ def eval_jahreszahl(update: Update, context: CallbackContext, echter_wert, richt
         update.message.reply_text(vorher_plural_text.format(abs(differenz)),
                                   reply_markup=ReplyKeyboardRemove())
 
-def eval_prozentzahl(update: Update, context: CallbackContext, echter_wert, richtig_text, falsch_text):
+def telegram_eval_prozentzahl(update: Update, context: CallbackContext, echter_wert, richtig_text, falsch_text):
     echter_wert = float(echter_wert)
     import re
     match = re.search(r"(?P<vorkomma>\d{1,2}),? ?(?P<nachkomma>\d{,2})", update.message.text)
@@ -38,7 +38,7 @@ def eval_prozentzahl(update: Update, context: CallbackContext, echter_wert, rich
                                   reply_markup=ReplyKeyboardRemove())
 
 
-action_functions = {"eval_jahreszahl": eval_jahreszahl,
-                    "eval_prozentzahl": eval_prozentzahl,
+telegram_action_functions = {"eval_jahreszahl": telegram_eval_jahreszahl,
+                    "eval_prozentzahl": telegram_eval_prozentzahl,
                     }
 
