@@ -1,13 +1,30 @@
 
 import re
 
-def readActions(format_inhalt_list):
+def readActions(format_inhalt_list, messanger="Telegram"):
     actions = []
     for format, inhalt in format_inhalt_list:
+        
+        format_split = format.split(" - ")
+        if len(format_split) == 2 and format_split[1] != messanger:
+            pass
+        elif len(format_split) == 2:
+            format = format_split[0]
 
         action = {}
 
         if format == "Textnachricht":
+            inhalt = inhalt.replace(".", "\.")
+            inhalt = inhalt.replace("(", "\(")
+            inhalt = inhalt.replace(")", "\)")
+            inhalt = inhalt.replace("!", "\!")
+            inhalt = inhalt.replace("?", "\?")
+            inhalt = inhalt.replace("-", "\-")
+            inhalt = inhalt.replace("+", "\+")
+            inhalt = inhalt.replace("#", "\#")
+
+            action["parse_mode"] = "MarkdownV2"
+
             action["type"] = "message"
             action["text"] = inhalt
 
@@ -37,6 +54,18 @@ def readActions(format_inhalt_list):
                 action["file"] = "assets/platzhalter.png"
                 action["caption"] = inhalt
 
+        elif format == "GIF":
+            action["type"] = "document"
+            regex = r"Datei: (?P<file>.*)\nAnzeigename: (?P<name>.*)"
+
+            match = re.search(regex, inhalt)
+            if match:
+                action["file"] = "assets/" + match.group('file')
+                action["caption"] = match.group('name')
+            else:
+                action["file"] = "assets/platzhalter.png"
+                action["caption"] = inhalt
+
         elif format == "GPS":
             action["type"] = "venue"
 
@@ -69,7 +98,7 @@ def readActions(format_inhalt_list):
                     inhalt, format))
         elif format == "Kontextspeicherung":
             action["type"] = "function"
-            action["func"] = "save_to_context"
+            action["func"] = "save_text_to_context"
             action["key"] = "name"
         elif format == "Return":
             action["type"] = "return"
