@@ -18,7 +18,7 @@ class Interaktion:
         self.action_requirements = action_requirements
 
     @classmethod
-    def from_excel_dict(cls, excel_dict_item):
+    def from_excel_dict(cls, excel_dict_item, messanger="Telegram"):
         actions = defaultdict(list)
         states = defaultdict(list)
         action_requirements = []
@@ -39,17 +39,18 @@ class Interaktion:
 
         if interaction_typ == "Aktion":
             actions["{}".format(poi_name)] = readActions(
-                interaktion_dict["Aktion"])
+                interaktion_dict["Aktion"], messanger=messanger)
 
         elif interaction_typ == "Verzweigung":
             actions["{}_weg".format(poi_name)] = readActions(interaktion_dict["Weg"]
-                                                               + [("Return", "{}_WEG".format(poi_name.upper()))])
+                                                             + [("Return", "{}_WEG".format(poi_name.upper()))], messanger=messanger)
             actions["{}_tipp".format(poi_name)] = readActions(
-                interaktion_dict["Tipp"])
+                interaktion_dict["Tipp"], messanger=messanger)
 
             for aktion, aktion_list in interaktion_dict.items():
                 if aktion.startswith("trigger_"):
-                    weiter_dict = dict((x, y) for x, y in interaktion_dict[aktion.replace("trigger_", "Next_")])
+                    weiter_dict = dict(
+                        (x, y) for x, y in interaktion_dict[aktion.replace("trigger_", "Next_")])
                     option_next_interaktion = "{}_{}".format(
                         weiter_dict["POI"], weiter_dict["Aktion"])
                     action_requirements.append(option_next_interaktion)
@@ -57,49 +58,56 @@ class Interaktion:
                     states["{}_WEG".format(poi_name.upper())] += readTriggers(
                         aktion_list, option_next_interaktion)
 
-
         elif interaction_typ == "Datenabfrage":
             actions["{}_frage".format(poi_name)] = readActions(interaktion_dict["Frage"]
-                                                               + [("Return", "{}_FRAGE".format(poi_name.upper()))])
+                                                               + [("Return", "{}_FRAGE".format(poi_name.upper()))], messanger=messanger)
             actions["{}_tipp".format(poi_name)] = readActions(
-                interaktion_dict["Tipp"])
+                interaktion_dict["Tipp"], messanger=messanger)
 
             states["{}_FRAGE".format(poi_name.upper())] = readTriggers(interaktion_dict["Typ"], next_interaktion) \
                 + [{"handler": "TypeHandler", "type": "Update",
                     "action": "{}_tipp".format(poi_name)}]
 
         elif interaction_typ == "Weg":
-            return Weg(poi_name, interaktion_dict)
+            return Weg(poi_name, interaktion_dict, messanger=messanger)
 
         elif interaction_typ == "Quizfrage":
             actions["{}_frage".format(poi_name)] = readActions(
-                interaktion_dict["Frage"] + [("Return", "{}_FRAGE".format(poi_name.upper()))])
+                interaktion_dict["Frage"] + [("Return", "{}_FRAGE".format(poi_name.upper()))], messanger=messanger)
 
             actions["{}_tipp".format(poi_name)] = readActions(
-                interaktion_dict["Tipp"])
+                interaktion_dict["Tipp"], messanger=messanger)
+
+            actions["{}_aufloesung".format(poi_name)] = readActions(
+                interaktion_dict["Aufloesung"], messanger=messanger)\
+                + readActions([("Return", "{}_AUFLOESUNG".format(poi_name.upper()))], messanger=messanger)
 
             for aktion, aktion_list in interaktion_dict.items():
                 if aktion.startswith("antwort_"):
-                    actions["{}_{}".format(poi_name, aktion)] = readActions(aktion_list) \
-                        + readActions(interaktion_dict["Aufloesung"]) \
-                        + readActions([("Return", "{}_AUFLOESUNG".format(poi_name.upper()))])
+                    actions["{}_{}".format(poi_name, aktion)] = readActions(aktion_list, messanger=messanger) \
+                        + readActions(interaktion_dict["Aufloesung"], messanger=messanger) \
+                        + readActions([("Return", "{}_AUFLOESUNG".format(poi_name.upper()))], messanger=messanger)
 
                 elif aktion.startswith("trigger_"):
                     states["{}_FRAGE".format(poi_name.upper())] += readTriggers(
                         aktion_list, "{}_{}".format(poi_name, aktion.replace("trigger_", "antwort_")))
 
+            states["{}_FRAGE".format(poi_name.upper())] += readTriggers([("Liste", "Weiter")], "{}_aufloesung".format(poi_name)) \
+                + [{"handler": "TypeHandler", "type": "Update",
+                    "action": "{}_tipp".format(poi_name)}]
+
             states["{}_AUFLOESUNG".format(poi_name.upper())] = readTriggers([("Liste", "Weiter")], next_interaktion) \
                 + [{"handler": "TypeHandler", "type": "Update", "action": "weiter_tipp"}]
 
         elif interaction_typ == "Schätzfrage":
             actions["{}_frage".format(poi_name)] = readActions(
-                interaktion_dict["Frage"] + [("Return", "{}_FRAGE".format(poi_name.upper()))])
+                interaktion_dict["Frage"] + [("Return", "{}_FRAGE".format(poi_name.upper()))], messanger=messanger)
 
-            actions["{}_aufloesung".format(poi_name)] = readActions(interaktion_dict["Aufloesung"]) \
-                + readActions([("Return", "{}_AUFLOESUNG".format(poi_name.upper()))])
+            actions["{}_aufloesung".format(poi_name)] = readActions(interaktion_dict["Aufloesung"], messanger=messanger) \
+                + readActions([("Return", "{}_AUFLOESUNG".format(poi_name.upper()))], messanger=messanger)
 
             actions["{}_tipp".format(poi_name)] = readActions(
-                interaktion_dict["Tipp"])
+                interaktion_dict["Tipp"], messanger=messanger)
 
             if interaktion_dict["Typ"][0][0] == "Jahreszahl":
                 states["{}_FRAGE".format(poi_name.upper())] = (readTriggers([("Regex", "^(\d{1,4})$")], "{}_aufloesung".format(poi_name))) \
@@ -125,15 +133,15 @@ class Interaktion:
 
         elif interaction_typ == "Listenfrage":
             actions["{}_frage".format(poi_name)] = readActions(
-                interaktion_dict["Frage"] + [("Return", "{}_FRAGE".format(poi_name.upper()))])
+                interaktion_dict["Frage"] + [("Return", "{}_FRAGE".format(poi_name.upper()))], messanger=messanger)
 
             answer_id_name_list = []
             for aktion, aktion_list in interaktion_dict.items():
                 if aktion.startswith("antwort_"):
-                    actions["{}_{}".format(poi_name, aktion)] = readActions([("Formel", "function: check_in_context\nkey: {}\nvalue: {}\ndoppelte_antwort: {}\n".format(poi_name, aktion.replace("antwort_", ""), interaktion_dict["doppelte Antwort"][0][1]))])\
-                        + readActions([("Formel", "function: append_to_context\nkey: {}\nvalue: {}".format(poi_name, aktion.replace("antwort_", "")))])\
-                        + readActions(aktion_list) \
-                        + readActions(interaktion_dict["richtig Antwort"])
+                    actions["{}_{}".format(poi_name, aktion)] = readActions([("Formel", "function: check_in_context\nkey: {}\nvalue: {}\ndoppelte_antwort: {}\n".format(poi_name, aktion.replace("antwort_", ""), interaktion_dict["doppelte Antwort"][0][1]))], messanger=messanger)\
+                        + readActions([("Formel", "function: append_to_context\nkey: {}\nvalue: {}".format(poi_name, aktion.replace("antwort_", "")))], messanger=messanger)\
+                        + readActions(aktion_list, messanger=messanger) \
+                        + readActions(interaktion_dict["richtig Antwort"], messanger=messanger)
 
                 elif aktion.startswith("trigger_"):
                     states["{}_FRAGE".format(poi_name.upper())] += readTriggers(
@@ -144,11 +152,11 @@ class Interaktion:
                         [aktion.replace("name_", ""), aktion_list[0][1]])
 
             actions["{}_aufloesung".format(poi_name)] = [{"type": "function", "func": "eval_list", "answer_id_name_list": answer_id_name_list, "poi": poi_name, "response_text": interaktion_dict["response_text"][0][1]}]\
-                + readActions(interaktion_dict["Aufloesung"]) \
-                + readActions([("Return", "{}_AUFLOESUNG".format(poi_name.upper()))])
+                + readActions(interaktion_dict["Aufloesung"], messanger=messanger) \
+                + readActions([("Return", "{}_AUFLOESUNG".format(poi_name.upper()))], messanger=messanger)
 
             actions["{}_falsche_antwort".format(poi_name)] = readActions(
-                interaktion_dict["falsch Antwort"])
+                interaktion_dict["falsch Antwort"], messanger=messanger)
 
             states["{}_FRAGE".format(poi_name.upper())] += readTriggers([("Liste", "Weiter")], "{}_aufloesung".format(poi_name))\
                 + [{"handler": "TypeHandler", "type": "Update",
@@ -158,12 +166,12 @@ class Interaktion:
                 + [{"handler": "TypeHandler", "type": "Update", "action": "weiter_tipp"}]
         elif interaction_typ == "Beteiligungsfrage":
             actions["{}_frage".format(poi_name)] = readActions(
-                interaktion_dict["Frage"] + [("Return", "{}_FRAGE".format(poi_name.upper()))])
+                interaktion_dict["Frage"] + [("Return", "{}_FRAGE".format(poi_name.upper()))], messanger=messanger)
             actions["{}_tipp".format(poi_name)] = readActions(
-                interaktion_dict["Tipp"])
+                interaktion_dict["Tipp"], messanger=messanger)
 
             actions["{}_aufloesung".format(poi_name)] = readActions(
-                interaktion_dict["Aufloesung"] + [("Return", "{}_AUFLOESUNG".format(poi_name.upper()))])
+                interaktion_dict["Aufloesung"] + [("Return", "{}_AUFLOESUNG".format(poi_name.upper()))], messanger=messanger)
 
             states["{}_FRAGE".format(poi_name.upper())] = readTriggers([("Liste", "Weiter")], next_interaktion) \
                 + readTriggers([("Liste", "Nein")], next_interaktion) \
@@ -176,13 +184,13 @@ class Interaktion:
 
         elif interaction_typ == "GIF Generator":
             actions["{}_frage".format(poi_name)] = readActions(
-                interaktion_dict["Frage"] + [("Return", "{}_FRAGE".format(poi_name.upper()))])
+                interaktion_dict["Frage"] + [("Return", "{}_FRAGE".format(poi_name.upper()))], messanger=messanger)
 
             actions["{}_tipp".format(poi_name)] = readActions(
-                interaktion_dict["Tipp"])
+                interaktion_dict["Tipp"], messanger=messanger)
 
             actions["{}_aufloesung".format(poi_name)] = readActions(
-                interaktion_dict["Aufloesung"])
+                interaktion_dict["Aufloesung"], messanger=messanger)
 
             states["{}_FRAGE".format(poi_name.upper())] = readTriggers([("Foto", "")], "{}_aufloesung".format(poi_name)) \
                 + readTriggers([("Liste", "Weiter")], next_interaktion) \
@@ -192,24 +200,24 @@ class Interaktion:
 
         elif interaction_typ == "Infostrecke":
             actions["{}_info".format(poi_name)] = readActions(
-                interaktion_dict["Info"] + [("Return", "{}_INFO".format(poi_name.upper()))])
+                interaktion_dict["Info"] + [("Return", "{}_INFO".format(poi_name.upper()))], messanger=messanger)
 
             states["{}_INFO".format(poi_name.upper())] = readTriggers([("Liste", "Weiter")], next_interaktion) \
                 + [{"handler": "TypeHandler", "type": "Update", "action": "weiter_tipp"}]
 
         elif interaction_typ == "Assoziationskette":
             actions["{}_frage".format(poi_name)] = readActions(
-                interaktion_dict["Frage"] + [("Return", "{}_FRAGE".format(poi_name.upper()))])
+                interaktion_dict["Frage"] + [("Return", "{}_FRAGE".format(poi_name.upper()))], messanger=messanger)
             actions["{}_loop".format(poi_name)] = readActions(
-                interaktion_dict["Loop"])
+                interaktion_dict["Loop"], messanger=messanger)
             states["{}_FRAGE".format(poi_name.upper())] = readTriggers([("Liste", "Weiter")], "{}_aufloesung".format(poi_name)) \
                 + readTriggers([("Freitext", "")], "{}_loop".format(poi_name)) \
                 + [{"handler": "TypeHandler", "type": "Update",
                     "action": "{}_tipp".format(poi_name)}]
             actions["{}_tipp".format(poi_name)] = readActions(
-                interaktion_dict["Tipp"])
+                interaktion_dict["Tipp"], messanger=messanger)
             actions["{}_aufloesung".format(poi_name)] = readActions(
-                interaktion_dict["Aufloesung"] + [("Return", "{}_AUFLOESUNG".format(poi_name.upper()))])
+                interaktion_dict["Aufloesung"] + [("Return", "{}_AUFLOESUNG".format(poi_name.upper()))], messanger=messanger)
 
             states["{}_AUFLOESUNG".format(poi_name.upper())] = readTriggers([("Liste", "Weiter")], next_interaktion) \
                 + [{"handler": "TypeHandler", "type": "Update", "action": "weiter_tipp"}]
