@@ -8,10 +8,10 @@ class Route:
         self.states = defaultdict(list)
         self.actions = defaultdict(list)
 
-    def from_excel_dict(self, excel_dict):
+    def from_excel_dict(self, excel_dict, messanger="Telegram"):
         for excel_dict_item in excel_dict.items():
         
-            interaktion = Interaktion.from_excel_dict(excel_dict_item)
+            interaktion = Interaktion.from_excel_dict(excel_dict_item, messanger=messanger)
             
             self.interaktionen.append(interaktion)
 
