@@ -4,11 +4,12 @@ from digitalguide.standardinteraktion.Trigger import readTriggers
 
 
 class Weg:
-    def __init__(self, poi_name, interaktion_dict):
+    def __init__(self, poi_name, interaktion_dict, messanger):
         self.typ = "Weg"
         self.name = poi_name
         self.interaktion_dict = interaktion_dict
-        self.action_requirements = [] 
+        self.action_requirements = []
+        self.messanger = messanger
 
         if "Next" in interaktion_dict.keys():
             weiter_dict = dict((x, y) for x, y in interaktion_dict["Next"])
@@ -55,21 +56,21 @@ class Weg:
         # Weg
         if "Weg" in self.interaktion_dict.keys():
             self.actions["{}_weg".format(self.name)] = readActions(self.interaktion_dict["Weg"]
-                                                                + [("Return", "{}_WEG".format(self.name.upper()))])
+                                                                + [("Return", "{}_WEG".format(self.name.upper()))], messanger=self.messanger)
         else:
             print("Error: {} hat keinen Weg.".format(self.name))
 
         # Navigation
         if "Navigation" in self.interaktion_dict.keys():
             self.actions["{}_navigation".format(self.name)] = readActions(
-                self.interaktion_dict["Navigation"])
+                self.interaktion_dict["Navigation"], messanger=self.messanger)
         else:
             print("Error: {} hat keine Navigation.".format(self.name))
 
         # Tipp
         if "Tipp" in self.interaktion_dict.keys():
             self.actions["{}_tipp".format(self.name)] = readActions(
-                self.interaktion_dict["Tipp"])
+                self.interaktion_dict["Tipp"], messanger=self.messanger)
             self.tipp_action = "{}_tipp".format(self.name)
         else:
             self.tipp_action = "weiter_wohin_tipp"
