@@ -15,7 +15,7 @@ client = session.client('s3',
                         aws_secret_access_key=os.getenv('SPACES_SECRET'))
 
 
-def write_photo(update, context, bucket, folder):
+def telegram_write_photo(update, context, bucket, folder):
     user_id = update.effective_user.id
     name = update.effective_user.name
 
@@ -28,7 +28,7 @@ def write_photo(update, context, bucket, folder):
                       #}
                       )
 
-def write_message(update, context, bucket, folder):
+def telegram_write_message(update, context, bucket, folder):
     user_id = update.effective_user.id
     name = update.effective_user.name
     message = update.effective_message.text
@@ -42,7 +42,7 @@ def write_message(update, context, bucket, folder):
                       #}
                       )
 
-def write_voice(update, context, bucket, folder):
+def telegram_write_voice(update, context, bucket, folder):
     user_id = update.effective_user.id
     name = update.effective_user.name
 
@@ -55,20 +55,20 @@ def write_voice(update, context, bucket, folder):
                     #}
                     )
 
-def write(update, context, bucket, folder):
+def telegram_write(update, context, bucket, folder):
     if type(update)==CallbackQuery:
         pass
     elif update.message.voice:
-        write_voice(update, context, bucket, folder)
+        telegram_write_voice(update, context, bucket, folder)
     elif update.message.text:
-        write_message(update, context, bucket, folder)
+        telegram_write_message(update, context, bucket, folder)
     elif update.message.photo:
-        write_photo(update, context, bucket, folder)
+        telegram_write_photo(update, context, bucket, folder)
     else:
         raise NotImplementedError("This type of update can not be saved")
 
-action_functions = {"write_photo": write_photo,
-                    "write_message": write_message,
-                    "write_voice": write_voice,
-                    "write": write
+telegram_action_functions = {"write_photo": telegram_write_photo,
+                    "write_message": telegram_write_message,
+                    "write_voice": telegram_write_voice,
+                    "write": telegram_write
                     }
\ No newline at end of file
